==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/es-VE/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Confirmar Eliminación Masiva de Activos',
  'bulk_delete_help'	=> 'Revisa los activos para eliminación masiva abajo. Una vez borrados, estos activos pueden ser restaurados, pero no estarán asociados con ningún usuario al que estén asignados actualmente.',
  'bulk_delete_warn'	=> 'Vas a eliminar :asset_count activos.',
	'bulk_update'		=> 'Actualización Masiva de Activos',
	'bulk_update_help'	=> 'Este formulario te permite actualizar múltiples activos de una vez. Sólo llena los campos que necesites cambiar. Cualquier campo dejado en blanco permanecerá sin cambios. ',
	'bulk_update_warn'	=> 'Estás a punto de editar las propiedades de :asset_count activos.',
    'checkedout_to'		=> 'Asignado A',
    'checkout_date'		=> 'Fecha de Salida',
    'checkin_date'		=> 'Fecha de Ingreso',
    'checkout_to'		=> 'Asignar A',
    'cost'				=> 'Costo de Compra',
    'create'			=> 'Crear Activo',
    'date'				=> 'Fecha de Compra',
    'depreciation'	    => 'Depreciación',
    'depreciates_on'	=> 'Se Deprecia En',
    'default_location'	=> 'Ubicación Predeterminada',
    'eol_date'			=> 'Fecha de Fin de Vida',
    'eol_rate'			=> 'Tasa de Fin de Vida',
    'expected_checkin'  => 'Fecha de Entrega Prevista',
    'expires'			=> 'Vence',
    'fully_depreciated'	=> 'Completamente Depreciado',
    'help_checkout'		=> 'Si deseas asignar este activo inmediatamente, selecciona "Listo para Asignar" de la lista de estados arriba. ',
    'mac_address'		=> 'Dirección MAC',
    'manufacturer'		=> 'Fabricante',
    'model'				=> 'Modelo',
    'months'			=> 'meses',
    'name'				=> 'Nombre de Activo',
    'notes'				=> 'Notas',
    'order'				=> 'Número de Orden',
    'qr'				=> 'Código QR',
    'requestable'		=> 'Los usuarios pueden solicitar este activo',
    'select_statustype'	=> 'Seleccionar Tipo de Estado',
    'serial'			=> 'Serial',
    'status'			=> 'Estado',
    'tag'				=> 'Etiqueta de Activo',
    'update'			=> 'Actualizar Activo',
    'warranty'			=> 'Garantía',
		'warranty_expires'		=> 'La garantía vence',
    'years'				=> 'años',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/es-VE/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Confirmar Eliminación Masiva de Activos',
  'bulk_delete_help'	=> 'Revisa los activos para eliminación masiva abajo. Una vez borrados, estos activos pueden ser restaurados, pero no estarán asociados con ningún usuario al que estén asignados actualmente.',
  'bulk_delete_warn'	=> 'Vas a eliminar :asset_count activos.',
    'bulk_update'		=> 'Actualización Masiva de Activos',
    'bulk_update_help'	=> 'Este formulario te permite actualizar múltiples activos de una vez. Sólo llena los campos que necesites cambiar. Cualquier campo dejado en blanco permanecerá sin cambios. ',
    'bulk_update_warn'	=> 'Estás a punto de editar las propiedades de :asset_count activos.',
    'checkedout_to'		=> 'Asignado A',
    'checkout_date'		=> 'Fecha de Salida',
    'checkin_date'		=> 'Fecha de Ingreso',
    'checkout_to'		=> 'Asignar A',
    'cost'				=> 'Costo de Compra',
    'create'			=> 'Crear Activo',
    'date'				=> 'Fecha de Compra',
    'depreciation'	    => 'Depreciación',
    'depreciates_on'	=> 'Se Deprecia En',
    'default_location'	=> 'Ubicación Predeterminada',
    'eol_date'			=> 'Fecha de Fin de Vida',
    'eol_rate'			=> 'Tasa de Fin de Vida',
    'expected_checkin'  => 'Fecha de Entrega Prevista',
    'expires'			=> 'Vence',
    'fully_depreciated'	=> 'Completamente Depreciado',
    'help_checkout'		=> 'Si deseas asignar este activo inmediatamente, selecciona "Listo para Asignar" de la lista de estados arriba. ',
    'mac_address'		=> 'Dirección MAC',
    'manufacturer'		=> 'Fabricante',
    'model'				=> 'Modelo',
    'months'			=> 'meses',
    'name'				=> 'Nombre de Activo',
    'notes'				=> 'Notas',
    'order'				=> 'Número de Orden',
    'qr'				=> 'Código QR',
    'requestable'		=> 'Los usuarios pueden solicitar este activo',
    'select_statustype'	=> 'Seleccionar Tipo de Estado',
    'serial'			=> 'Serial',
    'status'			=> 'Estado',
    'tag'				=> 'Etiqueta de Activo',
    'update'			=> 'Actualizar Activo',
    'warranty'			=> 'Garantía',
        'warranty_expires'		=> 'La garantía vence',
    'years'				=> 'años',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
